Login | Register For Free | Help
Search for: (Advanced)

Mailing List Archive: Quagga: Dev

[PATCH] [Zebra]: Changed the show command show ip/ipv6 mroute to show ip/ipv6 mbgp

 

 

Quagga dev RSS feed   Index | Next | Previous | View Threaded


balajig81 at gmail

Jul 18, 2012, 9:42 AM

Post #1 of 3 (197 views)
Permalink
[PATCH] [Zebra]: Changed the show command show ip/ipv6 mroute to show ip/ipv6 mbgp

From: "G.Balaji" <balajig81 [at] gmail>

---
zebra/zebra_vty.c | 26 +++++++++++++-------------
1 file changed, 13 insertions(+), 13 deletions(-)

diff --git a/zebra/zebra_vty.c b/zebra/zebra_vty.c
index 743c13f..917be52 100644
--- a/zebra/zebra_vty.c
+++ b/zebra/zebra_vty.c
@@ -1198,15 +1198,15 @@ DEFUN (show_ip_protocol,
}

/*
* Show IP mroute command to dump the BGP Multicast
* routing table
*/
-DEFUN (show_ip_mroute,
- show_ip_mroute_cmd,
- "show ip mroute",
+DEFUN (show_ip_mbgp,
+ show_ip_mbgp_cmd,
+ "show ip mbgp",
SHOW_STR
IP_STR
- "IP Multicast routing table\n")
+ "IP MBGP routing table\n")
{
struct route_table *table;
struct route_node *rn;
@@ -1990,12 +1990,12 @@ DEFUN (show_ipv6_route_summary,
* the Multicast routing table.
*/

-DEFUN (show_ipv6_mroute,
- show_ipv6_mroute_cmd,
- "show ipv6 mroute",
+DEFUN (show_ipv6_mbgp,
+ show_ipv6_mbgp_cmd,
+ "show ipv6 mbgp",
SHOW_STR
IP_STR
- "IPv6 Multicast routing table\n")
+ "IPv6 MBGP routing table\n")
{
struct route_table *table;
struct route_node *rn;
@@ -2162,8 +2162,8 @@ zebra_vty_init (void)
install_element (ENABLE_NODE, &show_ip_route_supernets_cmd);
install_element (ENABLE_NODE, &show_ip_route_summary_cmd);

- install_element (VIEW_NODE, &show_ip_mroute_cmd);
- install_element (ENABLE_NODE, &show_ip_mroute_cmd);
+ install_element (VIEW_NODE, &show_ip_mbgp_cmd);
+ install_element (ENABLE_NODE, &show_ip_mbgp_cmd);


#ifdef HAVE_IPV6
@@ -2196,7 +2196,7 @@ zebra_vty_init (void)
install_element (ENABLE_NODE, &show_ipv6_route_prefix_longer_cmd);
install_element (ENABLE_NODE, &show_ipv6_route_summary_cmd);

- install_element (VIEW_NODE, &show_ipv6_mroute_cmd);
- install_element (ENABLE_NODE, &show_ipv6_mroute_cmd);
+ install_element (VIEW_NODE, &show_ipv6_mbgp_cmd);
+ install_element (ENABLE_NODE, &show_ipv6_mbgp_cmd);
#endif /* HAVE_IPV6 */
}
@@ -1198,15 +1198,15 @@ DEFUN (show_ip_protocol,

/*
- * Show IP mroute command to dump the BGP Multicast
+ * Show IP mbgp command to dump the BGP Multicast
* routing table
*/
--
1.7.10.4

_______________________________________________
Quagga-dev mailing list
Quagga-dev [at] lists
http://lists.quagga.net/mailman/listinfo/quagga-dev


equinox at opensourcerouting

Jul 19, 2012, 8:12 AM

Post #2 of 3 (180 views)
Permalink
Re: [PATCH] [Zebra]: Changed the show command show ip/ipv6 mroute to show ip/ipv6 mbgp [In reply to]

On Wed, Jul 18, 2012 at 10:12:45PM +0530, G.Balaji wrote:
> -DEFUN (show_ip_mroute,
> - show_ip_mroute_cmd,
> - "show ip mroute",
> +DEFUN (show_ip_mbgp,
> + show_ip_mbgp_cmd,
> + "show ip mbgp",

This doesn't seem correct, the table should also contain static &
connected routes, as well as e.g. OSPF MT (if we supported that).

-David
Attachments: signature.asc (0.22 KB)


balajig81 at gmail

Jul 19, 2012, 8:41 AM

Post #3 of 3 (178 views)
Permalink
Re: [PATCH] [Zebra]: Changed the show command show ip/ipv6 mroute to show ip/ipv6 mbgp [In reply to]

Hi David

>This doesn't seem correct, the table should also contain static &
>connected routes, as well as e.g. OSPF MT (if we supported that).

Currently the MBGP table would also have connected routes installed. I
still have not changed the code for it to support redistribution of
OSPF/RIP routes into the BGP MRIB and static mroute is as well not
supported right now. Do we need that as well then i could send those
patches separately.

Cheers,
- Balaji

On Thu, Jul 19, 2012 at 8:42 PM, David Lamparter <
equinox [at] opensourcerouting> wrote:

> On Wed, Jul 18, 2012 at 10:12:45PM +0530, G.Balaji wrote:
> > -DEFUN (show_ip_mroute,
> > - show_ip_mroute_cmd,
> > - "show ip mroute",
> > +DEFUN (show_ip_mbgp,
> > + show_ip_mbgp_cmd,
> > + "show ip mbgp",
>
> This doesn't seem correct, the table should also contain static &
> connected routes, as well as e.g. OSPF MT (if we supported that).
>
> -David
>

Quagga dev RSS feed   Index | Next | Previous | View Threaded
 
 


Interested in having your list archived? Contact Gossamer Threads
 
  Web Applications & Managed Hosting Powered by Gossamer Threads Inc.